@@ -19,33 +19,30 @@ from pyasn1.type import opentype
 from pyasn1.type import univ
 from pyasn1.type import useful
 from pyasn1.codec.cer import encoder
-from pyasn1.compat.octets import ints2octs
 from pyasn1.error import PyAsn1Error
 
 
 class BooleanEncoderTestCase(BaseTestCase):
     def testTrue(self):
-        assert encoder.encode(univ.Boolean(1)) == ints2octs((1, 1, 255))
+        assert encoder.encode(univ.Boolean(1)) == bytes((1, 1, 255))
 
     def testFalse(self):
-        assert encoder.encode(univ.Boolean(0)) == ints2octs((1, 1, 0))
+        assert encoder.encode(univ.Boolean(0)) == bytes((1, 1, 0))
 
 
 class BitStringEncoderTestCase(BaseTestCase):
     def testShortMode(self):
-        assert encoder.encode(univ.BitString((1, 0) * 5)) == ints2octs(
-            (3, 3, 6, 170, 128)
-        )
+        assert encoder.encode(univ.BitString((1, 0) * 5)) == bytes((3, 3, 6, 170, 128))
 
     def testLongMode(self):
-        assert encoder.encode(univ.BitString((1, 0) * 501)) == ints2octs(
+        assert encoder.encode(univ.BitString((1, 0) * 501)) == bytes(
             (3, 127, 6) + (170,) * 125 + (128,)
         )
 
 
 class OctetStringEncoderTestCase(BaseTestCase):
     def testShortMode(self):
-        assert encoder.encode(univ.OctetString("Quick brown fox")) == ints2octs(
+        assert encoder.encode(univ.OctetString("Quick brown fox")) == bytes(
             (
                 4,
                 15,
@@ -68,7 +65,7 @@ class OctetStringEncoderTestCase(BaseTestCase):
         )
 
     def testLongMode(self):
-        assert encoder.encode(univ.OctetString("Q" * 1001)) == ints2octs(
+        assert encoder.encode(univ.OctetString("Q" * 1001)) == bytes(
             (36, 128, 4, 130, 3, 232) + (81,) * 1000 + (4, 1, 81, 0, 0)
         )
 
@@ -109,9 +106,7 @@ class GeneralizedTimeEncoderTestCase(BaseTestCase):
             assert 0, "Decimal comma tolerated"
 
     def testWithSubseconds(self):
-        assert encoder.encode(
-            useful.GeneralizedTime("20170801120112.59Z")
-        ) == ints2octs(
+        assert encoder.encode(useful.GeneralizedTime("20170801120112.59Z")) == bytes(
             (
                 24,
                 18,
@@ -137,9 +132,7 @@ class GeneralizedTimeEncoderTestCase(BaseTestCase):
         )
 
     def testWithSubsecondsWithZeros(self):
-        assert encoder.encode(
-            useful.GeneralizedTime("20170801120112.099Z")
-        ) == ints2octs(
+        assert encoder.encode(useful.GeneralizedTime("20170801120112.099Z")) == bytes(
             (
                 24,
                 18,
@@ -165,9 +158,7 @@ class GeneralizedTimeEncoderTestCase(BaseTestCase):
         )
 
     def testWithSubsecondsMax(self):
-        assert encoder.encode(
-            useful.GeneralizedTime("20170801120112.999Z")
-        ) == ints2octs(
+        assert encoder.encode(useful.GeneralizedTime("20170801120112.999Z")) == bytes(
             (
                 24,
                 19,
@@ -194,24 +185,22 @@ class GeneralizedTimeEncoderTestCase(BaseTestCase):
         )
 
     def testWithSubsecondsMin(self):
-        assert encoder.encode(
-            useful.GeneralizedTime("20170801120112.000Z")
-        ) == ints2octs(
+        assert encoder.encode(useful.GeneralizedTime("20170801120112.000Z")) == bytes(
             (24, 15, 50, 48, 49, 55, 48, 56, 48, 49, 49, 50, 48, 49, 49, 50, 90)
         )
 
     def testWithSubsecondsDanglingDot(self):
-        assert encoder.encode(useful.GeneralizedTime("20170801120112.Z")) == ints2octs(
+        assert encoder.encode(useful.GeneralizedTime("20170801120112.Z")) == bytes(
             (24, 15, 50, 48, 49, 55, 48, 56, 48, 49, 49, 50, 48, 49, 49, 50, 90)
         )
 
     def testWithSeconds(self):
-        assert encoder.encode(useful.GeneralizedTime("20170801120112Z")) == ints2octs(
+        assert encoder.encode(useful.GeneralizedTime("20170801120112Z")) == bytes(
             (24, 15, 50, 48, 49, 55, 48, 56, 48, 49, 49, 50, 48, 49, 49, 50, 90)
         )
 
     def testWithMinutes(self):
-        assert encoder.encode(useful.GeneralizedTime("201708011201Z")) == ints2octs(
+        assert encoder.encode(useful.GeneralizedTime("201708011201Z")) == bytes(
             (24, 13, 50, 48, 49, 55, 48, 56, 48, 49, 49, 50, 48, 49, 90)
         )
 
@@ -227,7 +216,7 @@ class UTCTimeEncoderTestCase(BaseTestCase):
 
     def testMissingTimezone(self):
         try:
-            assert encoder.encode(useful.UTCTime("150501120112")) == ints2octs(
+            assert encoder.encode(useful.UTCTime("150501120112")) == bytes(
                 (23, 13, 49, 53, 48, 53, 48, 49, 49, 50, 48, 49, 49, 50, 90)
             )
         except PyAsn1Error:
@@ -244,12 +233,12 @@ class UTCTimeEncoderTestCase(BaseTestCase):
             assert 0, "Local timezone tolerated"
 
     def testWithSeconds(self):
-        assert encoder.encode(useful.UTCTime("990801120112Z")) == ints2octs(
+        assert encoder.encode(useful.UTCTime("990801120112Z")) == bytes(
             (23, 13, 57, 57, 48, 56, 48, 49, 49, 50, 48, 49, 49, 50, 90)
         )
 
     def testWithMinutes(self):
-        assert encoder.encode(useful.UTCTime("9908011201Z")) == ints2octs(
+        assert encoder.encode(useful.UTCTime("9908011201Z")) == bytes(
             (23, 11, 57, 57, 48, 56, 48, 49, 49, 50, 48, 49, 90)
         )
 
@@ -258,31 +247,31 @@ class SequenceOfEncoderTestCase(BaseTestCase):
     def testEmpty(self):
         s = univ.SequenceOf()
         s.clear()
-        assert encoder.encode(s) == ints2octs((48, 128, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 0, 0))
 
     def testDefMode1(self):
         s = univ.SequenceOf()
         s.append(univ.OctetString("a"))
         s.append(univ.OctetString("ab"))
-        assert encoder.encode(s) == ints2octs((48, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0))
 
     def testDefMode2(self):
         s = univ.SequenceOf()
         s.append(univ.OctetString("ab"))
         s.append(univ.OctetString("a"))
-        assert encoder.encode(s) == ints2octs((48, 128, 4, 2, 97, 98, 4, 1, 97, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 4, 2, 97, 98, 4, 1, 97, 0, 0))
 
     def testDefMode3(self):
         s = univ.SequenceOf()
         s.append(univ.OctetString("b"))
         s.append(univ.OctetString("a"))
-        assert encoder.encode(s) == ints2octs((48, 128, 4, 1, 98, 4, 1, 97, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 4, 1, 98, 4, 1, 97, 0, 0))
 
     def testDefMode4(self):
         s = univ.SequenceOf()
         s.append(univ.OctetString("a"))
         s.append(univ.OctetString("b"))
-        assert encoder.encode(s) == ints2octs((48, 128, 4, 1, 97, 4, 1, 98, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 4, 1, 97, 4, 1, 98, 0, 0))
 
 
 class SequenceOfEncoderWithSchemaTestCase(BaseTestCase):
@@ -292,66 +281,62 @@ class SequenceOfEncoderWithSchemaTestCase(BaseTestCase):
 
     def testEmpty(self):
         self.s.clear()
-        assert encoder.encode(self.s) == ints2octs((48, 128, 0, 0))
+        assert encoder.encode(self.s) == bytes((48, 128, 0, 0))
 
     def testIndefMode1(self):
         self.s.clear()
         self.s.append("a")
         self.s.append("ab")
-        assert encoder.encode(self.s) == ints2octs(
-            (48, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0)
-        )
+        assert encoder.encode(self.s) == bytes((48, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0))
 
     def testIndefMode2(self):
         self.s.clear()
         self.s.append("ab")
         self.s.append("a")
-        assert encoder.encode(self.s) == ints2octs(
-            (48, 128, 4, 2, 97, 98, 4, 1, 97, 0, 0)
-        )
+        assert encoder.encode(self.s) == bytes((48, 128, 4, 2, 97, 98, 4, 1, 97, 0, 0))
 
     def testIndefMode3(self):
         self.s.clear()
         self.s.append("b")
         self.s.append("a")
-        assert encoder.encode(self.s) == ints2octs((48, 128, 4, 1, 98, 4, 1, 97, 0, 0))
+        assert encoder.encode(self.s) == bytes((48, 128, 4, 1, 98, 4, 1, 97, 0, 0))
 
     def testIndefMode4(self):
         self.s.clear()
         self.s.append("a")
         self.s.append("b")
-        assert encoder.encode(self.s) == ints2octs((48, 128, 4, 1, 97, 4, 1, 98, 0, 0))
+        assert encoder.encode(self.s) == bytes((48, 128, 4, 1, 97, 4, 1, 98, 0, 0))
 
 
 class SetOfEncoderTestCase(BaseTestCase):
     def testEmpty(self):
         s = univ.SetOf()
         s.clear()
-        assert encoder.encode(s) == ints2octs((49, 128, 0, 0))
+        assert encoder.encode(s) == bytes((49, 128, 0, 0))
 
     def testDefMode1(self):
         s = univ.SetOf()
         s.append(univ.OctetString("a"))
         s.append(univ.OctetString("ab"))
-        assert encoder.encode(s) == ints2octs((49, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0))
+        assert encoder.encode(s) == bytes((49, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0))
 
     def testDefMode2(self):
         s = univ.SetOf()
         s.append(univ.OctetString("ab"))
         s.append(univ.OctetString("a"))
-        assert encoder.encode(s) == ints2octs((49, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0))
+        assert encoder.encode(s) == bytes((49, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0))
 
     def testDefMode3(self):
         s = univ.SetOf()
         s.append(univ.OctetString("b"))
         s.append(univ.OctetString("a"))
-        assert encoder.encode(s) == ints2octs((49, 128, 4, 1, 97, 4, 1, 98, 0, 0))
+        assert encoder.encode(s) == bytes((49, 128, 4, 1, 97, 4, 1, 98, 0, 0))
 
     def testDefMode4(self):
         s = univ.SetOf()
         s.append(univ.OctetString("a"))
         s.append(univ.OctetString("b"))
-        assert encoder.encode(s) == ints2octs((49, 128, 4, 1, 97, 4, 1, 98, 0, 0))
+        assert encoder.encode(s) == bytes((49, 128, 4, 1, 97, 4, 1, 98, 0, 0))
 
 
 class SetOfEncoderWithSchemaTestCase(BaseTestCase):
@@ -361,39 +346,35 @@ class SetOfEncoderWithSchemaTestCase(BaseTestCase):
 
     def testEmpty(self):
         self.s.clear()
-        assert encoder.encode(self.s) == ints2octs((49, 128, 0, 0))
+        assert encoder.encode(self.s) == bytes((49, 128, 0, 0))
 
     def testIndefMode1(self):
         self.s.clear()
         self.s.append("a")
         self.s.append("ab")
 
-        assert encoder.encode(self.s) == ints2octs(
-            (49, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0)
-        )
+        assert encoder.encode(self.s) == bytes((49, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0))
 
     def testIndefMode2(self):
         self.s.clear()
         self.s.append("ab")
         self.s.append("a")
 
-        assert encoder.encode(self.s) == ints2octs(
-            (49, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0)
-        )
+        assert encoder.encode(self.s) == bytes((49, 128, 4, 1, 97, 4, 2, 97, 98, 0, 0))
 
     def testIndefMode3(self):
         self.s.clear()
         self.s.append("b")
         self.s.append("a")
 
-        assert encoder.encode(self.s) == ints2octs((49, 128, 4, 1, 97, 4, 1, 98, 0, 0))
+        assert encoder.encode(self.s) == bytes((49, 128, 4, 1, 97, 4, 1, 98, 0, 0))
 
     def testIndefMode4(self):
         self.s.clear()
         self.s.append("a")
         self.s.append("b")
 
-        assert encoder.encode(self.s) == ints2octs((49, 128, 4, 1, 97, 4, 1, 98, 0, 0))
+        assert encoder.encode(self.s) == bytes((49, 128, 4, 1, 97, 4, 1, 98, 0, 0))
 
 
 class SetEncoderTestCase(BaseTestCase):
@@ -405,7 +386,7 @@ class SetEncoderTestCase(BaseTestCase):
         self.s.setComponentByPosition(2, univ.Integer(1))
 
     def testIndefMode(self):
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 49,
                 128,
@@ -433,7 +414,7 @@ class SetEncoderTestCase(BaseTestCase):
         )
 
     def testWithOptionalIndefMode(self):
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 49,
                 128,
@@ -461,7 +442,7 @@ class SetEncoderTestCase(BaseTestCase):
         )
 
     def testWithDefaultedIndefMode(self):
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 49,
                 128,
@@ -489,7 +470,7 @@ class SetEncoderTestCase(BaseTestCase):
         )
 
     def testWithOptionalAndDefaultedIndefMode(self):
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 49,
                 128,
@@ -550,11 +531,11 @@ class SetEncoderWithSchemaTestCase(BaseTestCase):
 
     def testIndefMode(self):
         self.__init()
-        assert encoder.encode(self.s) == ints2octs((49, 128, 5, 0, 0, 0))
+        assert encoder.encode(self.s) == bytes((49, 128, 5, 0, 0, 0))
 
     def testWithOptionalIndefMode(self):
         self.__initWithOptional()
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 49,
                 128,
@@ -580,11 +561,11 @@ class SetEncoderWithSchemaTestCase(BaseTestCase):
 
     def testWithDefaultedIndefMode(self):
         self.__initWithDefaulted()
-        assert encoder.encode(self.s) == ints2octs((49, 128, 2, 1, 1, 5, 0, 0, 0))
+        assert encoder.encode(self.s) == bytes((49, 128, 2, 1, 1, 5, 0, 0, 0))
 
     def testWithOptionalAndDefaultedIndefMode(self):
         self.__initWithOptionalAndDefaulted()
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 49,
                 128,
@@ -631,7 +612,7 @@ class SetEncoderWithChoiceWithSchemaEncoderTestCase(BaseTestCase):
         self.s.setComponentByPosition(0)
         self.s.setComponentByName("status")
         self.s.getComponentByName("status").setComponentByPosition(0, 1)
-        assert encoder.encode(self.s) == ints2octs((49, 128, 1, 1, 255, 5, 0, 0, 0))
+        assert encoder.encode(self.s) == bytes((49, 128, 1, 1, 255, 5, 0, 0, 0))
 
 
 class SetEncoderWithTaggedChoiceEncoderTestCase(BaseTestCase):
@@ -653,7 +634,7 @@ class SetEncoderWithTaggedChoiceEncoderTestCase(BaseTestCase):
         s.setComponentByName("name", "A")
         s.getComponentByName("customer").setComponentByName("premium", True)
 
-        assert encoder.encode(s) == ints2octs((49, 128, 1, 1, 255, 4, 1, 65, 0, 0))
+        assert encoder.encode(s) == bytes((49, 128, 1, 1, 255, 4, 1, 65, 0, 0))
 
     def testWithTaggedChoice(self):
 
@@ -673,7 +654,7 @@ class SetEncoderWithTaggedChoiceEncoderTestCase(BaseTestCase):
         s.setComponentByName("name", "A")
         s.getComponentByName("customer").setComponentByName("premium", True)
 
-        assert encoder.encode(s) == ints2octs(
+        assert encoder.encode(s) == bytes(
             (49, 128, 4, 1, 65, 167, 128, 1, 1, 255, 0, 0, 0, 0)
         )
 
@@ -687,7 +668,7 @@ class SequenceEncoderTestCase(BaseTestCase):
         self.s.setComponentByPosition(2, univ.Integer(1))
 
     def testIndefMode(self):
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 48,
                 128,
@@ -715,7 +696,7 @@ class SequenceEncoderTestCase(BaseTestCase):
         )
 
     def testWithOptionalIndefMode(self):
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 48,
                 128,
@@ -743,7 +724,7 @@ class SequenceEncoderTestCase(BaseTestCase):
         )
 
     def testWithDefaultedIndefMode(self):
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 48,
                 128,
@@ -771,7 +752,7 @@ class SequenceEncoderTestCase(BaseTestCase):
         )
 
     def testWithOptionalAndDefaultedIndefMode(self):
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 48,
                 128,
@@ -832,11 +813,11 @@ class SequenceEncoderWithSchemaTestCase(BaseTestCase):
 
     def testIndefMode(self):
         self.__init()
-        assert encoder.encode(self.s) == ints2octs((48, 128, 5, 0, 0, 0))
+        assert encoder.encode(self.s) == bytes((48, 128, 5, 0, 0, 0))
 
     def testWithOptionalIndefMode(self):
         self.__initWithOptional()
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 48,
                 128,
@@ -862,11 +843,11 @@ class SequenceEncoderWithSchemaTestCase(BaseTestCase):
 
     def testWithDefaultedIndefMode(self):
         self.__initWithDefaulted()
-        assert encoder.encode(self.s) == ints2octs((48, 128, 5, 0, 2, 1, 1, 0, 0))
+        assert encoder.encode(self.s) == bytes((48, 128, 5, 0, 2, 1, 1, 0, 0))
 
     def testWithOptionalAndDefaultedIndefMode(self):
         self.__initWithOptionalAndDefaulted()
-        assert encoder.encode(self.s) == ints2octs(
+        assert encoder.encode(self.s) == bytes(
             (
                 48,
                 128,
@@ -912,7 +893,7 @@ class SequenceEncoderWithUntaggedOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1] = univ.Integer(12)
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 128, 2, 1, 1, 49, 50, 0, 0)
         )
 
@@ -922,7 +903,7 @@ class SequenceEncoderWithUntaggedOpenTypesTestCase(BaseTestCase):
         self.s[0] = 2
         self.s[1] = univ.OctetString("quick brown")
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 128, 2, 1, 2, 113, 117, 105, 99, 107, 32, 98, 114, 111, 119, 110, 0, 0)
         )
 
@@ -975,7 +956,7 @@ class SequenceEncoderWithImplicitlyTaggedOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1] = univ.Integer(12)
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 128, 2, 1, 1, 163, 128, 163, 128, 49, 50, 0, 0, 0, 0, 0, 0)
         )
 
@@ -1004,7 +985,7 @@ class SequenceEncoderWithExplicitlyTaggedOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1] = univ.Integer(12)
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 128, 2, 1, 1, 163, 128, 163, 128, 49, 50, 0, 0, 0, 0, 0, 0)
         )
 
@@ -1029,7 +1010,7 @@ class SequenceEncoderWithUntaggedSetOfOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1].append(univ.Integer(12))
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (48, 128, 2, 1, 1, 49, 128, 49, 50, 0, 0, 0, 0)
         )
 
@@ -1039,7 +1020,7 @@ class SequenceEncoderWithUntaggedSetOfOpenTypesTestCase(BaseTestCase):
         self.s[0] = 2
         self.s[1].append(univ.OctetString("quick brown"))
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (
                 48,
                 128,
@@ -1119,7 +1100,7 @@ class SequenceEncoderWithImplicitlyTaggedSetOfOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1].append(univ.Integer(12))
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (
                 48,
                 128,
@@ -1174,7 +1155,7 @@ class SequenceEncoderWithExplicitlyTaggedSetOfOpenTypesTestCase(BaseTestCase):
         self.s[0] = 1
         self.s[1].append(univ.Integer(12))
 
-        assert encoder.encode(self.s, asn1Spec=self.s) == ints2octs(
+        assert encoder.encode(self.s, asn1Spec=self.s) == bytes(
             (
                 48,
                 128,
@@ -1264,39 +1245,39 @@ class NestedOptionalSequenceEncoderTestCase(BaseTestCase):
 
     def testOptionalWithDefaultAndOptional(self):
         s = self.__initOptionalWithDefaultAndOptional()
-        assert encoder.encode(s) == ints2octs(
+        assert encoder.encode(s) == bytes(
             (48, 128, 48, 128, 4, 4, 116, 101, 115, 116, 2, 1, 123, 0, 0, 0, 0)
         )
 
     def testOptionalWithDefault(self):
         s = self.__initOptionalWithDefault()
-        assert encoder.encode(s) == ints2octs((48, 128, 48, 128, 2, 1, 123, 0, 0, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 48, 128, 2, 1, 123, 0, 0, 0, 0))
 
     def testOptionalWithOptional(self):
         s = self.__initOptionalWithOptional()
-        assert encoder.encode(s) == ints2octs(
+        assert encoder.encode(s) == bytes(
             (48, 128, 48, 128, 4, 4, 116, 101, 115, 116, 0, 0, 0, 0)
         )
 
     def testOptional(self):
         s = self.__initOptional()
-        assert encoder.encode(s) == ints2octs((48, 128, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 0, 0))
 
     def testDefaultWithDefaultAndOptional(self):
         s = self.__initDefaultWithDefaultAndOptional()
-        assert encoder.encode(s) == ints2octs(
+        assert encoder.encode(s) == bytes(
             (48, 128, 48, 128, 4, 4, 116, 101, 115, 116, 2, 1, 123, 0, 0, 0, 0)
         )
 
     def testDefaultWithDefault(self):
         s = self.__initDefaultWithDefault()
-        assert encoder.encode(s) == ints2octs(
+        assert encoder.encode(s) == bytes(
             (48, 128, 48, 128, 4, 4, 116, 101, 115, 116, 0, 0, 0, 0)
         )
 
     def testDefaultWithOptional(self):
         s = self.__initDefaultWithOptional()
-        assert encoder.encode(s) == ints2octs((48, 128, 48, 128, 2, 1, 123, 0, 0, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 48, 128, 2, 1, 123, 0, 0, 0, 0))
 
 
 class NestedOptionalChoiceEncoderTestCase(BaseTestCase):
@@ -1346,23 +1327,23 @@ class NestedOptionalChoiceEncoderTestCase(BaseTestCase):
 
     def testOptionalWithDefaultAndOptional(self):
         s = self.__initOptionalWithDefaultAndOptional()
-        assert encoder.encode(s) == ints2octs(
+        assert encoder.encode(s) == bytes(
             (48, 128, 48, 128, 4, 4, 116, 101, 115, 116, 2, 1, 123, 0, 0, 0, 0)
         )
 
     def testOptionalWithDefault(self):
         s = self.__initOptionalWithDefault()
-        assert encoder.encode(s) == ints2octs((48, 128, 48, 128, 2, 1, 123, 0, 0, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 48, 128, 2, 1, 123, 0, 0, 0, 0))
 
     def testOptionalWithOptional(self):
         s = self.__initOptionalWithOptional()
-        assert encoder.encode(s) == ints2octs(
+        assert encoder.encode(s) == bytes(
             (48, 128, 48, 128, 4, 4, 116, 101, 115, 116, 0, 0, 0, 0)
         )
 
     def testOptional(self):
         s = self.__initOptional()
-        assert encoder.encode(s) == ints2octs((48, 128, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 0, 0))
 
 
 class NestedOptionalSequenceOfEncoderTestCase(BaseTestCase):
@@ -1389,13 +1370,13 @@ class NestedOptionalSequenceOfEncoderTestCase(BaseTestCase):
 
     def testOptionalWithValue(self):
         s = self.__initOptionalWithValue()
-        assert encoder.encode(s) == ints2octs(
+        assert encoder.encode(s) == bytes(
             (48, 128, 48, 128, 4, 4, 116, 101, 115, 116, 0, 0, 0, 0)
         )
 
     def testOptional(self):
         s = self.__initOptional()
-        assert encoder.encode(s) == ints2octs((48, 128, 0, 0))
+        assert encoder.encode(s) == bytes((48, 128, 0, 0))
 
 
 suite = unittest.TestLoader().loadTestsFromModule(sys.modules[__name__])
